@@ -3,6 +3,8 @@ package IPC::PubSub::Cache::JiftyDBI::Stash::Item;
 use warnings;
 use strict;
 
+use vars qw/$TABLE_PREFIX/;
+
 use Jifty::DBI::Schema;
 use Jifty::DBI::Record schema {
     column key    => type is 'text';
@@ -10,6 +12,19 @@ use Jifty::DBI::Record schema {
     column expiry => type is 'int';
 };
 
+
+sub table_prefix {
+    my $self = shift;
+    $TABLE_PREFIX = shift if (@_);
+    return ($TABLE_PREFIX);
+}
+
+sub table {
+    my $self = shift;
+    return $self->table_prefix . $self->SUPER::table();
+}
+
+
 package IPC::PubSub::Cache::JiftyDBI::Stash::ItemCollection;
 use base qw/Jifty::DBI::Collection/;
 
