@@ -3,6 +3,8 @@ package IPC::PubSub::Cache::JiftyDBI::Stash::Publisher;
 use warnings;
 use strict;
 
+use vars qw/$TABLE_PREFIX/;
+
 use Jifty::DBI::Schema;
 use Jifty::DBI::Record schema {
     column channel    => type is 'text';
@@ -11,6 +13,17 @@ use Jifty::DBI::Record schema {
 };
 
 
+sub table_prefix {
+    my $self = shift;
+    $TABLE_PREFIX = shift if (@_);
+    return ($TABLE_PREFIX);
+}
+
+sub table {
+    my $self = shift;
+    return $self->table_prefix . $self->SUPER::table();
+}
+
 package IPC::PubSub::Cache::JiftyDBI::Stash::PublisherCollection;
 use base qw/Jifty::DBI::Collection/;
 
